##  Overview
IT components represent the technology (software and hardware) or services that an organization's applications depend on. To operate, IT components consume energy. Understanding the energy consumption levels of IT components allows organizations to effectively manage associated costs and plan their sustainability initiatives. For more information, visit [IT Component Modeling Guidelines](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model IT components. This includes best practices and applicable use cases, and common antipatterns.").
In this tutorial, you will learn how to set up an automation to assign tags to IT component fact sheets based on their energy consumption values. Tags represent T-shirt sizes for each determined energy consumption range, such as XS, S, M, L, and XL.
The automation triggers every time the fact sheet field associated with energy consumption is updated. Based on this value, the corresponding tag representing a T-shirt size is assigned to the IT component fact sheet.
